@@ -61,150 +61,6 @@ impl<'a> Input<'a> {
   pub fn builder() -> build::InputBuilderInit<'a> {
     build::InputBuilderInit::new()
   }
-  /// Create an Input Block from a text Label and interactive element.
-  ///
-  /// # Arguments
-  ///
-  /// - `label` - A label that appears above an input element in the form of
-  ///     a [text object 🔗] that must have type of `plain_text`.
-  ///     Maximum length for the text in this field is 2000 characters.
-  ///
-  /// - `element` - An interactive `block_element` that will be used to gather
-  ///     the input for this block.
-  ///     For the kinds of Elements supported by
-  ///     Input blocks, see the `SupportedElement` enum.
-  ///     For info about Block Elements in general,
-  ///     see the `elems` module.
-  ///
-  /// [text object 🔗]: https://api.slack.com/reference/messaging/composition-objects#text
-  ///
-  /// # Example
-  /// ```
-  /// use slack_blocks::elems::Select;
-  /// use slack_blocks::blocks;
-  ///
-  /// let label = "On a scale from 1 - 5, how angsty are you?";
-  /// let input = Select::from_placeholder_and_action_id("Pick a channel...", "ABC123")
-  ///     .choose_from_public_channels();
-  ///
-  /// let block = blocks::Input::from_label_and_element(label, input);
-  ///
-  /// // < send to slack API >
-  /// ```
-  pub fn from_label_and_element(label: impl Into<text::Plain>,
-                                element: impl Into<SupportedElement<'a>>)
-                                -> Self {
-    Input { label: label.into().into(),
-            element: element.into(),
-            block_id: None,
-            hint: None,
-            dispatch_action: None,
-            optional: None }
-  }
-
-  /// Set a unique `block_id` to identify this instance of an Input Block.
-  ///
-  /// # Arguments
-  ///
-  /// - `block_id` - A string acting as a unique identifier for a block.
-  ///     You can use this `block_id` when you receive an interaction
-  ///     payload to [identify the source of the action 🔗].
-  ///     If not specified, one will be generated.
-  ///     Maximum length for this field is 255 characters.
-  ///     `block_id` should be unique for each message and each iteration of a message.
-  ///     If a message is updated, use a new `block_id`.
-  ///
-  /// [identify the source of the action 🔗]: https://api.slack.com/interactivity/handling#payloads
-  ///
-  /// # Example
-  /// ```
-  /// use slack_blocks::elems::Select;
-  /// use slack_blocks::blocks;
-  ///
-  /// let label = "On a scale from 1 - 5, how angsty are you?";
-  /// let input = Select::from_placeholder_and_action_id("Pick a channel...", "ABC123")
-  ///     .choose_from_public_channels();
-  ///
-  /// let block = blocks::Input
-  ///     ::from_label_and_element(label, input)
-  ///     .with_block_id("angst_rating_12345");
-  ///
-  /// // < send to slack API >
-  /// ```
-  pub fn with_block_id(mut self, block_id: impl Into<Cow<'a, str>>) -> Self {
-    self.block_id = Some(block_id.into());
-    self
-  }
-
-  /// Set the `hint` on this Input Block that appears below
-  /// an input element in a lighter grey.
-  ///
-  /// # Arguments
-  ///
-  /// - `hint` - An optional hint that appears below an input element
-  ///     in a lighter grey.
-  ///     It must be a a [text object 🔗] with a `type` of `plain_text`.
-  ///     Maximum length for the `text` in this field is 2000 characters.
-  ///
-  /// [text object 🔗]: https://api.slack.com/reference/messaging/composition-objects#text
-  ///
-  /// # Example
-  /// ```
-  /// use slack_blocks::elems::Select;
-  /// use slack_blocks::blocks;
-  ///
-  /// # use std::error::Error;
-  /// # pub fn main() -> Result<(), Box<dyn Error>> {
-  /// let label = "On a scale from 1 - 5, how angsty are you?";
-  /// let input = Select::from_placeholder_and_action_id("Pick a channel...", "ABC123")
-  ///     .choose_from_public_channels();
-  ///
-  /// let block = blocks::Input
-  ///     ::from_label_and_element(label, input)
-  ///     .with_hint("PSST hey! Don't let them know how angsty you are!");
-  ///
-  /// // < send to slack API >
-  /// # Ok(())
-  /// # }
-  /// ```
-  pub fn with_hint(mut self, hint: impl Into<text::Plain>) -> Self {
-    self.hint = Some(hint.into().into());
-    self
-  }
-
-  /// Set whether or not this input is Optional.
-  ///
-  /// # Arguments
-  /// - `optionality` - A boolean that indicates whether the input
-  ///     element may be empty when a user submits the modal.
-  ///     Defaults to false.
-  ///
-  /// # Example
-  /// ```
-  /// use slack_blocks::elems::Select;
-  /// use slack_blocks::blocks;
-  ///
-  /// let label = "On a scale from 1 - 5, how angsty are you?";
-  /// let input = Select::from_placeholder_and_action_id("Pick a channel...", "ABC123")
-  ///     .choose_from_public_channels();
-  ///
-  /// let block = blocks::Input
-  ///     ::from_label_and_element(label, input)
-  ///     .with_hint("PSST hey! Don't even answer that!")
-  ///     .with_optional(true);
-  ///
-  /// // < send to slack API >
-  /// ```
-  pub fn with_optional(mut self, optionality: bool) -> Self {
-    self.optional = Some(optionality);
-    self
-  }
-
-  /// Will allow the elements in this block to dispatch block_actions payloads. Defaults to false.
-  pub fn dispatch_block_actions(mut self) -> Self {
-    self.dispatch_action = Some(true);
-    self
-  }
 
   /// Validate that this Input block agrees with Slack's model requirements
   ///
@@ -218,17 +74,21 @@ impl<'a> Input<'a> {
   ///
   /// # Example
   /// ```
-  /// use slack_blocks::elems::Select;
-  /// use slack_blocks::blocks;
+  /// use slack_blocks::{blocks, elems::select};
+  ///
+  /// let select =
+  ///   select::PublicChannel::builder().placeholder("Pick a channel...")
+  ///                                   .action_id("ABC123")
+  ///                                   .build();
   ///
-  /// let label = "On a scale from 1 - 5, how angsty are you?";
-  /// let input = Select::from_placeholder_and_action_id("Pick a channel...", "ABC123")
-  ///     .choose_from_public_channels();
   /// let long_string = std::iter::repeat(' ').take(2001).collect::<String>();
   ///
   /// let block = blocks::Input
-  ///     ::from_label_and_element(label, input)
-  ///     .with_block_id(long_string);
+  ///     ::builder()
+  ///     .label("On a scale from 1 - 5, how angsty are you?")
+  ///     .element(select)
+  ///     .block_id(long_string)
+  ///     .build();
   ///
   /// assert_eq!(true, matches!(block.validate(), Err(_)));
   ///
@@ -345,6 +205,41 @@ pub mod build {
       self.block_id = Some(block_id.into());
       self
     }
+
+    /// Set `dispatch_action` (Optional)
+    ///
+    /// Will allow the elements in this block to
+    /// dispatch block_actions payloads.
+    ///
+    /// Defaults to false.
+    pub fn dispatch_actions(mut self, should: bool) -> Self {
+      self.dispatch_action = Some(should);
+      self
+    }
+
+    /// Sets `optional` (**Required**)
+    ///
+    /// A boolean that indicates whether the input
+    /// element may be empty when a user submits the modal.
+    ///
+    /// Defaults to false.
+    pub fn optional(mut self, optional: bool) -> Self {
+      self.optional = Some(optional);
+      self
+    }
+
+    /// Set `hint` (Optional)
+    ///
+    /// An optional hint that appears below an input element
+    /// in a lighter grey.
+    ///
+    /// Maximum length for the text in this field is 2000 characters.
+    pub fn hint<T>(mut self, hint: T) -> Self
+      where T: Into<text::Plain>
+    {
+      self.hint = Some(hint.into().into());
+      self
+    }
   }
 
   impl<'a, L> InputBuilder<'a, RequiredMethodNotCalled<method::element>, L> {
@@ -370,8 +265,8 @@ pub mod build {
     }
 
     /// XML child alias for `element`
-    #[cfg(feature = "xml")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "xml")))]
+    #[cfg(feature = "blox")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "blox")))]
     pub fn child<El>(self,
                      element: El)
                      -> InputBuilder<'a, Set<method::element>, L>
