@@ -44,153 +44,17 @@ impl<'a> User<'a> {
   ///                    elems::{select, BlockElement},
   ///                    text};
   ///
-  /// let select: BlockElement =
+  /// let select =
   ///   select::User::builder().placeholder("Choose your favorite coworker!")
   ///                          .action_id("fave_fren")
-  ///                          .build()
-  ///                          .into();
+  ///                          .build();
   ///
-  /// let block: Block = Actions::try_from(select).unwrap().into();
+  /// let block: Block = Actions::builder().element(select).build().into();
   /// ```
   pub fn builder() -> build::UserBuilderInit<'a> {
     build::UserBuilderInit::new()
   }
 
-  /// Construct a Select element, letting users choose a user from their workspace.
-  ///
-  /// # Arguments
-  /// - `placeholder` - A [`plain_text` only text object 🔗] that defines
-  ///     the placeholder text shown on the menu.
-  ///     Maximum length for the `text` in this field is 150 characters.
-  ///
-  /// - `action_id` - An identifier for the action triggered when a menu option is selected.
-  ///     You can use this when you receive an interaction payload to [identify the source of the action 🔗].
-  ///     Should be unique among all other `action_id`s used elsewhere by your app.
-  ///     Maximum length for this field is 255 characters.
-  ///
-  /// [`plain_text` only text object 🔗]: https://api.slack.comhttps://api.slack.com/reference/block-kit/composition-objects#text
-  /// [identify the source of the action 🔗]: https://api.slack.comhttps://api.slack.com/interactivity/handling#payloads
-  ///
-  /// # Example
-  /// ```
-  /// use std::convert::TryFrom;
-  /// use std::iter;
-  ///
-  /// use slack_blocks::elems::{BlockElement, select};
-  /// use slack_blocks::blocks;
-  /// use slack_blocks::text;
-  /// use text::ToSlackPlaintext;
-  ///
-  /// let select: BlockElement = select::User
-  ///                                  ::from_placeholder_and_action_id("Channel", "ABC123")
-  ///                                   .into();
-  ///
-  /// let title = "Pick a user to ban...".plaintext();
-  ///
-  /// let blocks: Vec<blocks::Block> = vec![
-  ///     blocks::Section::from_text(title).into(),
-  ///     blocks::Actions::try_from(vec![select]).unwrap().into(),
-  /// ];
-  ///
-  /// // <send `blocks` to slack's API>
-  /// ```
-  #[deprecated(since = "0.16.8", note = "use select::User::builder instead.")]
-  pub fn from_placeholder_and_action_id(placeholder: impl Into<text::Plain>,
-                                        action_id: impl Into<Cow<'a, str>>)
-                                        -> Self {
-    Self { placeholder: placeholder.into().into(),
-           action_id: action_id.into(),
-           confirm: None,
-           initial_user: None }
-  }
-
-  /// Optional method that allows you to add a
-  /// confirmation dialog that appears after a
-  /// menu item is selected.
-  ///
-  /// # Arguments
-  /// - `confirm` - A [confirm object 🔗] that defines an
-  ///     optional confirmation dialog that appears after
-  ///     a menu item is selected.
-  ///
-  /// [confirm object 🔗]: https://api.slack.comhttps://api.slack.com/reference/block-kit/composition-objects#confirm
-  ///
-  /// # Example
-  /// ```
-  /// use std::iter;
-  /// use std::convert::TryFrom;
-  ///
-  /// use slack_blocks::{
-  ///   blocks::{Block, Actions},
-  ///   elems::{BlockElement, select::Select},
-  ///   compose::{text, Confirm, text::ToSlackPlaintext},
-  /// };
-  ///
-  /// # use std::error::Error;
-  /// # pub fn main() -> Result<(), Box<dyn Error>> {
-  ///
-  /// let confirm = Confirm::from_parts(
-  ///   "Are you sure?",
-  ///   "Think hard about this.".plaintext(),
-  ///   "Yes",
-  ///   "No",
-  /// );
-  ///
-  /// let select: BlockElement = Select::from_placeholder_and_action_id("Pick a user to ban!", "ban_hammer")
-  ///                                   .with_confirm(confirm)
-  ///                                   .choose_from_users()
-  ///                                   .into();
-  ///
-  /// let block: Block = Actions::try_from(select).unwrap().into();
-  ///
-  /// // < send `block` to slack API >
-  /// # Ok(())
-  /// # }
-  /// ```
-  #[deprecated(since = "0.16.8", note = "use select::User::builder instead.")]
-  pub fn with_confirm(mut self, confirm: Confirm) -> Self {
-    self.confirm = Some(confirm);
-    self
-  }
-
-  /// Pre-select a user
-  ///
-  /// # Arguments
-  /// - `user_id` - The ID of any valid public channel to be
-  ///     pre-selected when the menu loads.
-  ///
-  /// # Example
-  /// ```
-  /// use std::convert::TryFrom;
-  ///
-  /// use slack_blocks::{
-  ///   blocks::{Block, Actions, Section},
-  ///   elems::{BlockElement, select::Select},
-  ///   compose::{text, Confirm, text::ToSlackPlaintext},
-  /// };
-  ///
-  /// # let your_mom = "";
-  /// let select: BlockElement = Select::from_placeholder_and_action_id(
-  ///                                     "Pick a user to send a cat gif to!",
-  ///                                     "cat_gif_recipient"
-  ///                                   )
-  ///                                   .choose_from_users()
-  ///                                   .with_initial_user(your_mom)
-  ///                                   .into();
-  ///
-  /// let blocks: Vec<Block> = vec![
-  ///     Section::from_text("Pick a channel to send your poll to...".plaintext()).into(),
-  ///     Actions::try_from(select).unwrap().into(),
-  /// ];
-  ///
-  /// // <send to slack's API>
-  /// ```
-  #[deprecated(since = "0.16.8", note = "use select::User::builder instead.")]
-  pub fn with_initial_user(mut self, user_id: impl Into<Cow<'a, str>>) -> Self {
-    self.initial_user = Some(user_id.into());
-    self
-  }
-
   /// Validate that this user select agrees with Slack's model requirements
   ///
   /// # Errors
@@ -203,15 +67,16 @@ impl<'a> User<'a> {
   /// ```
   /// use slack_blocks::elems::select;
   ///
-  /// let select = select::User::from_placeholder_and_action_id(
-  ///         r#"Hey I really would appreciate it if you chose
+  /// let select = select::User::builder().placeholder(
+  ///                           r#"Hey I really would appreciate it if you chose
   ///         a channel relatively soon, so that we can figure out
   ///         where we need to send this poll, ok? it's kind of
   ///         important that you specify where this poll should be
   ///         sent, in case we haven't made that super clear.
   ///         If you understand, could you pick a channel, already??"#,
-  ///         "ABC123"
-  ///     );
+  /// )
+  ///              .action_id("ABC123")
+  ///              .build();
   ///
   /// assert!(matches!(select.validate(), Err(_)))
   /// ```
@@ -263,15 +128,11 @@ pub mod build {
   ///                    compose::Opt,
   ///                    elems::{select::User, BlockElement}};
   ///
-  /// let select: BlockElement =
-  ///   User::builder().placeholder("Choose your favorite co-worker!")
-  ///                  .action_id("favorite_coworker")
-  ///                  .build()
-  ///                  .into();
+  /// let select = User::builder().placeholder("Choose your favorite co-worker!")
+  ///                             .action_id("favorite_coworker")
+  ///                             .build();
   ///
-  /// let block: Block =
-  ///   Actions::try_from(select).expect("actions supports select elements")
-  ///                            .into();
+  /// let block: Block = Actions::builder().element(select).build().into();
   ///
   /// // <send block to API>
   /// ```
