@@ -2,10 +2,12 @@
 //! the Rust ecosystem.
 //!
 //! Inside, you'll find models for all of Slack's Layout Blocks,
-//! Block Elements, and Composition Objects.
+//! Block Elements, and Composition Objects. Each structure has Slack's API
+//! documentation copied in-place so you don't have to leave your editor to
+//! remember the details of the block kit API.
 //!
 //! Every model has builders that leverage Rust's type system
-//! to help you make sure what you're sending to Slack is 100% valid to them.
+//! to help you provide every required field, so you can be confident in your app.
 //!
 //! ## Troubleshooting common compiler errors
 //! `Method build not found for ...Builder` - Dig into the error message,
@@ -50,7 +52,7 @@
 //!
 //! Or enable the `unstable` feature and use xml macros:
 //! ```rust
-//! use slack_blocks::mox::*;
+//! use slack_blocks::blox::*;
 //!
 //! let pick_date = blox! {
 //!   <date_picker action_id="datepicker123"
@@ -78,14 +80,13 @@
                    unreachable_pub,
                    unsafe_code,
                    unused_crate_dependencies))]
-#![allow(deprecated)] // temporary
 
 #[macro_use]
 extern crate validator_derive;
 
-#[cfg(feature = "xml")]
-#[cfg_attr(docsrs, doc(cfg(feature = "xml")))]
-pub mod mox;
+#[cfg(feature = "blox")]
+#[cfg_attr(docsrs, doc(cfg(feature = "blox")))]
+pub mod blox;
 
 #[doc(inline)]
 pub mod blocks;
